@@ -44,7 +44,7 @@ static off_t read_all;
 static off_t buffer_size_local;
 static char *buffrom;
 static char *bufto;
-static long psize = 0;
+static long psize;
 
 // 関数プロトタイプ
 void compare_memcmp(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpdd);
