@@ -19,12 +19,12 @@
 	cpinfo->write = false;
 
 // 関数プロトタイプ
-static inline _Bool create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd) __attribute__((always_inline));
+static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd) __attribute__((always_inline));
 static inline _Bool c_s(const OPArg *oparg, const CPInfo *cpinfo, CPDD *cpdd) __attribute__((always_inline));
 /*******************************************************************************
 シンボリックリンクを作成
 *******************************************************************************/
-static inline _Bool create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
+static inline void create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD *cpdd)
 {
 	_Bool check;
 	struct stat stat_from;
@@ -128,7 +128,7 @@ static inline _Bool create_symboliclink(const OPArg *oparg, CPInfo *cpinfo, CPDD
 		}
 	}
 
-	return check;
+	cpinfo->write = check;
 }
 
 /*******************************************************************************
