@@ -95,7 +95,7 @@ static int ifrom;
 static int ito;
 static int rbuf_num;
 static int wbuf_num;
-static long psize = 0;
+static long psize;
 static _Bool from_open;
 static _Bool from_stat;
 static _Bool to_open;
@@ -104,14 +104,14 @@ static _Bool to_open;
 char *write_now;
 
 // 関数プロトタイプ
-_Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
+void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd);
 static void * read_thread(void *unknown);
 static void * write_thread(void *unknown);
 static void * do_md5_append(void *tmp);
 
 /*******************************************************************************
 *******************************************************************************/
-_Bool read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
+void read_write(const OPArg *oparg, CPInfo *cpinfo, SDir *sdir, CPDD *cpdd)
 {
 	static struct stat stat_buf;
 	static _Bool filesystem_check = false;
@@ -655,6 +655,15 @@ LOOP_END:
 
 	write_now = NULL;
 
+	if((from_open == true) && (to_open == true) && (total_read_local == total_write_local))
+	{
+		cpinfo->write = true;
+	}
+	else
+	{
+		cpinfo->write = false;
+	}
+
 	if(oparg->CHECK_MODE == BEFORE)
 	{
 		switch(oparg->CHECK)
@@ -681,7 +690,7 @@ LOOP_END:
 			break;
 
 		case V_FIVE:
-			if(cpinfo->verify_md5 != NULL)
+			if((cpinfo->verify_md5 != NULL) && (cpinfo->write = true))
 			{
 				verify_hash(oparg, cpinfo, sdir, cpdd);
 			}
@@ -705,15 +714,6 @@ LOOP_END:
 			puts("");
 		}
 	}
-
-	if((from_open == true) && (to_open == true))
-	{
-		return true;
-	}
-	else
-	{
-		return false;
-	}
 }
 
 /*******************************************************************************
