@@ -22,7 +22,7 @@
 static void *buf[BUF_NUM];
 static int fd;
 static int buffer_size_local;
-static long psize = 0;
+static long psize;
 static md5_state_t state;
 static md5_byte_t digest[16];
 static int read_size[BUF_NUM];
@@ -43,6 +43,7 @@ static void * append_func(void *dummy);
 *******************************************************************************/
 void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpdd)
 {
+	static _Bool get_memory = false;
 	fd = 0;
 	buffer_size_local = oparg->buffer_size / 2;
 	read_size[0] = 0;
@@ -88,15 +89,23 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 
 	if(open_flag == true)
 	{
-		if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
+		if(buf[0] == NULL)
 		{
-			fprintf(stderr, "ベリファイに失敗しました\n");
-			fprintf(stderr, "%s\n", cpinfo->to);
-			print_error("posix_memalign", __FILE__, __LINE__, cpdd);
-			write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
-			cpinfo->write = false;
+			if((posix_memalign((void **)&buf[0], psize, buffer_size_local) != 0) || (posix_memalign((void **)&buf[1], psize, buffer_size_local) != 0))
+			{
+				fprintf(stderr, "ベリファイに失敗しました\n");
+				fprintf(stderr, "%s\n", cpinfo->to);
+				print_error("posix_memalign", __FILE__, __LINE__, cpdd);
+				write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
+				cpinfo->write = false;
+			}
+			else
+			{
+				get_memory = true;
+			}
 		}
-		else
+
+		if(get_memory == true)
 		{
 			md5_init(&state);
 
@@ -172,6 +181,14 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 				unlink(cpinfo->to);
 			}
 		}
+		else
+		{
+			fprintf(stderr, "ベリファイ出来ません\n");
+			fprintf(stderr, "メモリの確保に失敗しました\n");
+			print_error(__func__, __FILE__, __LINE__, cpdd);
+			write_log_hash_check(cpinfo, cpinfo->verify_md5, "NULL", sdir, cpdd, false);
+			cpinfo->write = false;
+		}
 	}
 	else
 	{
@@ -182,8 +199,8 @@ void verify_hash(const OPArg *oparg, CPInfo *cpinfo, const SDir *sdir, CPDD *cpd
 		cpinfo->write = false;
 	}
 
-	free(buf[0]);
-	free(buf[1]);
+//	free(buf[0]);
+//	free(buf[1]);
 }
 
 /*******************************************************************************
